.. _sec-bibliography:

Bibliography
============

.. [AC2004] S. Abramsky, B. Coecke. `A Categorical Semantics for Quantum Protocols <https://arxiv.org/pdf/quant-ph/0402130.pdf>`_, LiCS 2004

.. [SC2021] S. Clark. `Something Old, Something New: Grammar-based CCG Parsing with Transformer Models <https://arxiv.org/pdf/2109.10044.pdf>`_, `arXiv:2109.10044`, 2021

.. [CSC2010] B. Coecke, M. Sadrzadeh, S. Clark. `Mathematical Foundations for a Compositional Distributional Model of Meaning <https://arxiv.org/pdf/1003.4394.pdf>`_, `Lambek Festschirft`, special issue of `Linguistic Analysis`, 2010

.. [CW2021] B. Coecke, V. Wang. `Grammar Equations <https://arxiv.org/pdf/2106.07485.pdf>`_, `SemSpace 2021`

.. [FTC2020] G. de Felice, A. Toumi, B. Coecke. `DisCoPy: Monoidal Categories in Python <https://arxiv.org/pdf/2005.02975.pdf>`_, `ACT 2020`

.. [HS2007] J. Hockenmaier, M. Steedman. `CCGbank: A Corpus of CCG Derivations and Dependency Structures Extracted from the Penn Treebank <https://aclanthology.org/J07-3004.pdf>`_, `Computational Linguistics, Volume 33, Number 3`, September 2007

.. [HV2013] C. Heunen, J. Vicary. `Introduction to Categorical Quantum Mechanics <http://www.cs.ox.ac.uk/people/jamie.vicary/IntroductionToCategoricalQuantumMechanics.pdf>`_, `Course Notes`, Oxford University, 2013

.. [Kar2016] D. Kartsaklis. `Coordination in Categorical Compositional Distributional Semantics <https://arxiv.org/pdf/1606.01515.pdf>`_, `SemSpace 2016`

.. [Kea2014] D. Kartsaklis, M. Sadrzadeh, S. Pulman, B. Coecke. `Reasoning about Meaning in Natural Language with Compact Closed Categories and Frobenius Algebras <https://arxiv.org/pdf/1401.5980.pdf>`_, `Logic and Algebraic Structures in Quantum Computing and Information`, 2014

.. [Kea2021] D. Kartsaklis, I. Fan, R. Yeung, A. Pearson, R. Lorenz, A. Toumi, G. de Felice, K. Meichanetzidis, S. Clark, B. Coecke. `lambeq: An Efficient High-Level Python Library for Quantum NLP <https://arxiv.org/pdf/2110.04236.pdf>`_, `arXiv:2110.04236`, 2021

.. [Lam1999] J. Lambek. Type Grammar Revisited, `Logical Aspects of Computational Linguistics`, 1999

.. [Lea2021] R. Lorenz, A. Pearson, K. Meichanetzidis, D. Kartsaklis, B. Coecke. `QNLP in Practice: Running Compositional Models of Meaning on a Quantum Computer <https://arxiv.org/pdf/2102.12846.pdf>`_ `arXiv:2102.12846`, 2021

.. [Mea2020] K. Meichanetzidis, A. Toumi, G. de Felice, B. Coecke. `Grammar-Aware Question-Answering on Quantum Computers <https://arxiv.org/pdf/2012.03756.pdf>`_, `arXiv:2012.03756`, 2020

.. [Rea2016] L. Rimell, J. Maillard, T. Polajnar, S. Clark. `RELPRON: A Relative Clause Evaluation Data Set for Compositional Distributional Semantics <https://direct.mit.edu/coli/article/42/4/661/1555/RELPRON-A-Relative-Clause-Evaluation-Data-Set-for>`_, `Computational Linguistics`, 2016

.. [SCC2014a] M. Sadrzadeh, S. Clark, B. Coecke. `The Frobenius Anatomy of Word Meanings I: Subject and Object Relative Pronouns <https://arxiv.org/pdf/1404.5278.pdf>`_, `Journal of Logic and Computation`, 2014

.. [SCC2014b] M. Sadrzadeh, S. Clark, B. Coecke. `The Frobenius Anatomy of Word Meanings II: Possessive Relative Pronouns <https://arxiv.org/pdf/1406.4690.pdf>`_, `Journal of Logic and Computation`, 2014

.. [SJA2019] S. Sim, P. Johnson, A. Aspuru-Guzik. `Expressibility and Entangling Capability of Parameterized Quantum Circuits for Hybrid Quantum-Classical Algorithms <https://arxiv.org/pdf/1905.10876.pdf>`_, `arXiv:1905.10876`, 2019

.. [Spa1998] J. C. Spall, `Implementation of the simultaneous perturbation algorithm for stochastic optimization <https://ieeexplore.ieee.org/document/705889>`_, `IEEE Transactions on Aerospace and Electronic Systems`, 1998

.. [Ste2000] M. Steedman. The Syntactic Process, MIT Press, 2000

.. [YK2021] R. Yeung, D. Kartsaklis. `A CCG-Based Version of the DisCoCat Framework <https://aclanthology.org/2021.semspace-1.3.pdf>`_, `SemSpace 2021`

.. [YNM2017] M. Yoshikawa, H. Noji, Y. Matsumoto. `A* CCG Parsing with a Supertag and Dependency Factored Model <https://arxiv.org/pdf/1704.06936.pdf>`_, `ACL 2017`
